@@ -1,33 +1,35 @@
-use 5.010;
+use 5.008;
 use strict;
 use warnings;
 
 package Tie::Moose;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
-use Carp 'croak';
 use Moose;
+use namespace::autoclean;
+use Carp qw( croak );
+use Types::Standard -types;
 
 with 'MooseX::Traits';
 
 has object => (
 	is       => 'ro',
-	isa      => 'Object',
+	isa      => Object,
 	required => 1,
 );
 
 has attributes => (
 	is       => 'ro',
-	isa      => 'ArrayRef[ArrayRef[Str|Undef]]',
+	isa      => ArrayRef[ ArrayRef[ Maybe[Str] ] ],
 	lazy     => 1,
 	builder  => '_build_attributes',
 );
 
 has attributes_hash => (
 	is       => 'ro',
-	isa      => 'HashRef[ArrayRef[Str|Undef]]',
+	isa      => HashRef[ ArrayRef[ Maybe[Str] ] ],
 	lazy     => 1,
 	builder  => '_build_attributes_hash',
 );
@@ -166,8 +168,6 @@ sub SCALAR
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
-
 1;
 
 __END__
